Image Keyword Tool
==================

Image Keyword Tool (IKT) is command-line utility that simplify usage of deep
learning libraries for image tags generation.

.. toctree::
   :maxdepth: 2

   README
   CONTRIBUTING
   CODE_OF_CONDUCT
   changelog
   contributors
